@@ -4,30 +4,40 @@
 #' across all phases.
 #'
 #' @inheritParams .inheritParams
-#' @param lag.max The lag up to which autocorrelations will be computed.
-#' Default is \code{lag.max = 3}.
+#' @param lag_max,lag.max The lag up to which autocorrelations will be computed.
 #' @param ... Further arguments passed to the \code{\link{acf}} function
-#' @return A data frame containing separate autocorrelations for each
-#' phase and for all phases (for each single-case). If \code{lag.max} exceeds
-#' the length of a phase minus one, NA is returned for this cell.
+#' @return A data frame containing separate autocorrelations for each phase and
+#'   for all phases (for each single-case). If \code{lag_max} exceeds the length
+#'   of a phase minus one, NA is returned for this cell.
 #' @author Juergen Wilbert
 #' @seealso \code{\link{trend}}, \code{\link{plm}}, \code{\link{acf}}
 #' @examples
 #' ## Compute autocorrelations for a list of four single-cases up to lag 2.
-#' autocorr(Huber2014, lag.max = 2)
+#' autocorr(Huber2014, lag_max = 2)
 #' @concept Autocorrelation
 #' @concept Serial correlation
 #' @export
-autocorr <- function(data, dvar, pvar, mvar, lag.max = 3, ...) {
-  if (missing(dvar)) dvar <- scdf_attr(data, .opt$dv) else scdf_attr(data, .opt$dv) <- dvar
-  if (missing(pvar)) pvar <- scdf_attr(data, .opt$phase) else scdf_attr(data, .opt$phase) <- pvar
-  if (missing(mvar)) mvar <- scdf_attr(data, .opt$mt) else scdf_attr(data, .opt$mt) <- mvar
+autocorr <- function(data, dvar, pvar, mvar, 
+                     lag_max = 3,
+                     lag.max, 
+                     ...) {
+  
+  if (!missing(lag.max)) lag_max <- lag.max
+  
+  # set defaults attributes
+  if (missing(dvar)) dvar <- scdf_attr(data, .opt$dv) 
+  if (missing(pvar)) pvar <- scdf_attr(data, .opt$phase) 
+  if (missing(mvar)) mvar <- scdf_attr(data, .opt$mt) 
+  
+  scdf_attr(data, .opt$dv) <- dvar
+  scdf_attr(data, .opt$phase) <- pvar
+  scdf_attr(data, .opt$mt) <- mvar
 
   data <- .prepare_scdf(data)
 
   N <- length(data)
   case_names <- .case_names(names(data), length(data))
-  var_lag <- paste0("Lag ", 1:lag.max)
+  var_lag <- paste0("Lag ", 1:lag_max)
   
   ac <- list()
   for (case in 1:N) {
@@ -44,14 +54,14 @@ autocorr <- function(data, dvar, pvar, mvar, lag.max = 3, ...) {
     df <- data.frame(Phase = c(phases$values, "all"))
     for (phase in 1:length(phases$values)) {
       y <- data[[case]][phases$start[phase]:phases$stop[phase], dvar]
-      if (length(y) - 1 < lag.max) lag <- length(y) - 1 else lag <- lag.max
+      if (length(y) - 1 < lag_max) lag <- length(y) - 1 else lag <- lag_max
 
       .tmp <- acf(y, lag.max = lag, plot = FALSE, ...)$acf[-1]
       df[phase, var_lag[1:lag]] <- .tmp
     }
     
     y <- data[[case]][[dvar]]
-    if (length(y) - 1 < lag.max) lag <- length(y) - 1 else lag <- lag.max
+    if (length(y) - 1 < lag_max) lag <- length(y) - 1 else lag <- lag_max
 
     .tmp <- acf(y, lag.max = lag, plot = FALSE, ...)$acf[-1]
     df[length(phases$values) + 1, var_lag[1:lag]] <- .tmp
@@ -72,9 +82,9 @@ autocorr <- function(data, dvar, pvar, mvar, lag.max = 3, ...) {
   out
 }
 
-#' @rdname autocorr
+#' @rdname deprecated-functions
 #' @export
 autocorrSC <- function(...) {
   .deprecated_warning("autocorr", "autocorrSC")
   autocorr(...)
-  }
\ No newline at end of file
+  }
